validate_namespace

Function validate_namespace 

pub fn validate_namespace(
    labels: &Labels,
    tags: &Tags,
    plugs: &[Plug],
    sockets: &[Socket],
) -> Result<(), AttributeError>
Validate the three-tier namespace-uniqueness rule (SRD-0005 D5).

Enforces:

  • Port names are unique across plugs and sockets on one element.
  • No key appears in more than one tier (label / tag / port).