pub struct ElementTypeDescriptor {
pub type_id: TypeId,
pub required_labels: BTreeSet<LabelKey>,
pub forbidden_labels: BTreeMap<LabelKey, String>,
pub label_warnings: BTreeMap<LabelKey, String>,
pub provides_infrastructure: bool,
}Expand description
Metadata the compiler uses to validate an element of this type.
Fields
type_id: TypeIdCanonical type id.
required_labels: BTreeSet<LabelKey>Labels that elements of this type must carry.
forbidden_labels: BTreeMap<LabelKey, String>Labels that are forbidden on elements of this type, keyed by label with a message explaining why.
label_warnings: BTreeMap<LabelKey, String>Labels whose presence triggers a warning (not an error).
provides_infrastructure: booltrue if this type represents infrastructure (a node).
Implementations
Sourceimpl ElementTypeDescriptor
impl ElementTypeDescriptor
Sourcepub fn builder() -> ElementTypeDescriptorBuilder
pub fn builder() -> ElementTypeDescriptorBuilder
Create an instance of ElementTypeDescriptor using the builder syntax